@@ -43,10 +43,10 @@ class Client(object):
         return self.workspace.file.list_absolute_path()
     def get_binary(self, absolutePath):
         return self.workspace.file.get_content(absolutePath)
-    def get_csv(self, absolutePath):
-        return self.workspace.file.get_csv(absolutePath)
-    def get_json(self, absolutePath):
-        return self.workspace.file.get_json(absolutePath)
+    def get_csv_wrapper(self, absolutePath):
+        return self.workspace.file.get_csv_wrapper(absolutePath)
+    def get_json_wrapper(self, absolutePath):
+        return self.workspace.file.get_json_wrapper(absolutePath)
     def execute(self, sql):
         cursor = self.workspace.statement.execute(sql);
         return cursor
